/** @fluent/sequence@0.8.0 */
(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define('@fluent/sequence', ['exports'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.FluentSequence = {}));
})(this, (function (exports) { 'use strict';

    /**
     * Synchronously map an identifier or an array of identifiers to the best
     * `FluentBundle` instance(s).
     *
     * @param bundles - An iterable of bundles to sift through.
     * @param ids - An id or ids to map.
     */
    function mapBundleSync(bundles, ids) {
        if (!Array.isArray(ids)) {
            return getBundleForId(bundles, ids);
        }
        return ids.map(id => getBundleForId(bundles, id));
    }
    /*
     * Find the best `FluentBundle` with the translation for `id`.
     */
    function getBundleForId(bundles, id) {
        for (const bundle of bundles) {
            if (bundle.hasMessage(id)) {
                return bundle;
            }
        }
        return null;
    }

    /**
     * Asynchronously map an identifier or an array of identifiers to the best
     * `FluentBundle` instance(s).
     *
     * @param bundles - An iterable of bundles to sift through.
     * @param ids - An id or ids to map.
     */
    async function mapBundleAsync(bundles, ids) {
        if (!Array.isArray(ids)) {
            for await (const bundle of bundles) {
                if (bundle.hasMessage(ids)) {
                    return bundle;
                }
            }
            return null;
        }
        const foundBundles = new Array(ids.length).fill(null);
        let remainingCount = ids.length;
        for await (const bundle of bundles) {
            for (const [index, id] of ids.entries()) {
                if (!foundBundles[index] && bundle.hasMessage(id)) {
                    foundBundles[index] = bundle;
                    remainingCount--;
                }
                // Return early when all ids have been mapped to bundles.
                if (remainingCount === 0) {
                    return foundBundles;
                }
            }
        }
        return foundBundles;
    }

    exports.mapBundleAsync = mapBundleAsync;
    exports.mapBundleSync = mapBundleSync;

}));
